-----
iobes
-----

.. image:: https://img.shields.io/pypi/v/iobes
    :target: https://pypi.org/project/iobes/
    :alt: PyPI Version
.. image:: https://github.com/blester125/iobes/workflows/Unit%20Test/badge.svg
    :target: https://github.com/blester125/iobes/actions
    :alt: Actions Status    
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code style: black
.. image:: https://readthedocs.org/projects/iobes/badge/?version=latest
    :target: https://iobes.readthedocs.io/en/latest/index.html
    :alt: Documentation Status

A light-weight library for creating span level annotations from token level decisions.

Details and an explaination on *why* you should use this library can be found in the `paper`_

.. _paper: https://arxiv.org/pdf/2010.04373.pdf

--------
Citation
--------

If you use this library in your research I would appreciate if you would cite the following:

.. code:: BibTex

    @article{lester-2020-iobes,
      title={iobes: A Library for Span-Level Processing},
      author={Lester, Brian},
      journal={arXiv preprint arXiv:2010.04373},
      year={2020},
      url={https://arxiv.org/pdf/2010.04373.pdf}
    }
